# PySheets

PySheets is a spreadsheet UI for Python, implemented in Python, running logic and saving data in the browser, using PyScript and IndexedDB.

# Licensing

PySheets is free to use for personal use. If you use it in a commercial setting, please get a [license](https://buy.stripe.com/00g1684SS2BZ9Es7st). Of course, if you use PySheets for personal project and 
you really like it, you can still sponsor the project and buy a license.
  
# Installation

To install PySheets on your local machine, run:

```
pip install pysheets-app
```

Do not install `pysheets`, this is an unrelated dormant project.

# Using

To run PySheets locally on your own machine, storing all data in the browser, without any server, run:

```
pysheets
```

This should open http://localhost:8081/ in your browser and show a button to create a new sheet.

Things to try:
 - Change the sheet name
 - Add literal values in the sheet
 - Import a sheet from the web (see the AI section)

